<?php
/**
 * Plugin Name: SWO plugin
 * Description: Custom SWO plugin
 * Version: 1.0.0
 * Author: SWO VeV-VA
 */



// For Developer Information see
// https://developer.wordpress.org/plugins/plugin-basics/



/**
 * Admin style and script files
 * https://developer.wordpress.org/reference/functions/wp_enqueue_style/
 * https://developer.wordpress.org/reference/functions/wp_enqueue_script/
 * https://developer.wordpress.org/reference/hooks/admin_enqueue_scripts/
 */
function swo_plugin_admin_files() {
    wp_enqueue_style('custom_admin_style', plugin_dir_url( __FILE__ ).'admin/css/admin.css');
    wp_enqueue_script('custom_admin_script', plugin_dir_url( __FILE__ ).'admin/js/admin.js', array(), null, true);
}
//add_action('admin_enqueue_scripts', "swo_plugin_admin_files");



/**
 * Theme style and script files
 * https://developer.wordpress.org/reference/functions/wp_enqueue_style/
 * https://developer.wordpress.org/reference/functions/wp_enqueue_script/
 * https://developer.wordpress.org/reference/hooks/wp_enqueue_scripts/
 */
function swo_plugin_files() {
    wp_enqueue_style('custom_style', plugin_dir_url( __FILE__ ).'public/css/public.css');
    wp_enqueue_script('custom_script', plugin_dir_url( __FILE__ ).'public/js/public.js', array(), null, true);
}
//add_action('wp_enqueue_scripts', "swo_plugin_files");



/**
 * Automatically set metadata on image upload
 * https://developer.wordpress.org/reference/functions/wp_attachment_is_image/
 * https://developer.wordpress.org/reference/functions/get_post/
 * https://developer.wordpress.org/reference/functions/update_post_meta/
 * https://developer.wordpress.org/reference/hooks/add_attachment/
 */
function swo_plugin_set_metadata_on_image_upload( $post_ID ) {

	// Check if uploaded file is an image
	if ( wp_attachment_is_image( $post_ID ) ) {

		// Get the image title
		$image_title = get_post( $post_ID )->post_title;
		
		// Set the image alt text
		update_post_meta( $post_ID, '_wp_attachment_image_alt', $image_title );
	} 
}
add_action( 'add_attachment', 'swo_plugin_set_metadata_on_image_upload' );



/**
 * Custom SWO pattern
 * https://developer.wordpress.org/block-editor/reference-guides/block-api/block-patterns/
 */
add_action( 'init', function() {

    register_block_pattern_category(
        'custom-patterns',
        array( 'label' => esc_html__( 'Custom patterns', 'swo-plugin' ) ) );

    register_block_pattern(
        'swo-plugin/custom-swo-pattern',
        array(
            'title'			=> __( 'Custom SWO pattern', 'swo-plugin' ),
            'description'	=> _x( 'A block with 2 columns that displays an avatar image, a heading and a paragraph.', 'Block pattern description', 'swo-plugin' ),
            'content'		=> '<!-- wp:columns {"verticalAlignment":null} --> <div class="wp-block-columns"><!-- wp:column {"verticalAlignment":"center","width":"33.33%"} --> <div class="wp-block-column is-vertically-aligned-center" style="flex-basis:33.33%"><!-- wp:image {"id":29,"sizeSlug":"large","linkDestination":"none","className":"is-style-rounded"} --> <figure class="wp-block-image size-large is-style-rounded"><img src="' . esc_url( plugin_dir_url( __FILE__ ) ) . '/assets/images/logo.png" alt="Kinsta" /></figure> <!-- /wp:image --></div> <!-- /wp:column --> <!-- wp:column {"width":"66.66%"} --> <div class="wp-block-column" style="flex-basis:66.66%"><!-- wp:heading {"level":4} --> <h4>Výchozí nadpis</h4> <!-- /wp:heading --> <!-- wp:paragraph --> <p>Lorem ipsum (zkráceně lipsum) je označení pro standardní pseudolatinský text užívaný v grafickém designu a navrhování jako demonstrativní výplňový text při vytváření pracovních ukázek grafických návrhů (např. internetových stránek, rozvržení časopisů či všech druhů reklamních materiálů).</p> <!-- /wp:paragraph --></div> <!-- /wp:column --></div> <!-- /wp:columns -->',
            'categories'	=> array( 'custom-patterns' ),
        )
    );
});


/**
 * Disable
 */
/*add_action( 'init', function() {
    define( 'SWO_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );

    // Always 
    require_once( SWO_PLUGIN_DIR . 'disable/comments-completely.php' );

    // Not administrator role
    if (!current_user_can('administrator')) {

        // Preview and Administration mode
        require_once( SWO_PLUGIN_DIR . 'disable/admin-bar.php' );
        
        // Administration mode only
        if (is_admin()) {
            require_once( SWO_PLUGIN_DIR . 'disable/dashboard.php' );
            require_once( SWO_PLUGIN_DIR . 'disable/admin-menu.php' );
            // require_once( SWO_PLUGIN_DIR . 'disable/site-health.php' );
        }
    }
});*/